#    Copyright (C) 2009 William.os4y@gmail.com
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, version 2 of the License.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
SERVER_IDENT = "fapws3/0.8.1"
send_traceback_to_browser=True
#in case of False for send_traceback_to_browser, send_traceback_short will be sent to the browser
send_traceback_short="<h1>Error</h1>Please contact your administrator"
date_format="%a, %d %b %Y %H:%M:%S GMT"
